@@ -1,11 +1,11 @@
 package Mojolicious::Plugin::Moai;
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 # ABSTRACT: Mojolicious UI components using modern UI libraries
 
 #pod =head1 SYNOPSIS
 #pod
 #pod     use Mojolicious::Lite;
-#pod     plugin Moai => 'Bootstrap4';
+#pod     plugin Moai => 'Bootstrap4'; # or 'Bulma'
 #pod     app->start;
 #pod     __DATA__
 #pod     @@ list.html.ep
@@ -31,6 +31,10 @@ our $VERSION = '0.003';
 #pod
 #pod L<http://getbootstrap.com>
 #pod
+#pod =head2 Bulma
+#pod
+#pod L<http://bulma.io>
+#pod
 #pod =head1 WIDGETS
 #pod
 #pod Widgets are snippets that you can include in your templates using the
@@ -209,8 +213,6 @@ our $VERSION = '0.003';
 #pod
 #pod =item * Bootstrap 3
 #pod
-#pod =item * Bulma
-#pod
 #pod =item * Material
 #pod
 #pod =back
@@ -300,12 +302,12 @@ Mojolicious::Plugin::Moai - Mojolicious UI components using modern UI libraries
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
     use Mojolicious::Lite;
-    plugin Moai => 'Bootstrap4';
+    plugin Moai => 'Bootstrap4'; # or 'Bulma'
     app->start;
     __DATA__
     @@ list.html.ep
@@ -331,6 +333,10 @@ L</moai/lib>, below.
 
 L<http://getbootstrap.com>
 
+=head2 Bulma
+
+L<http://bulma.io>
+
 =head1 WIDGETS
 
 Widgets are snippets that you can include in your templates using the
@@ -509,8 +515,6 @@ There should be support for...
 
 =item * Bootstrap 3
 
-=item * Bulma
-
 =item * Material
 
 =back
